@@ -71,6 +71,7 @@ public:
     }
     QAbstractItemModel *layersModel() const override;
     void opaqueAction(const Okular::BackendOpaqueAction *action) override;
+    void freeOpaqueActionContents(const Okular::BackendOpaqueAction &action) override;
 
     // [INHERITED] document information
     bool isAllowed(Okular::Permission permission) const override;
@@ -79,7 +80,7 @@ public:
     QImage image(Okular::PixmapRequest *request) override;
 
     // [INHERITED] print page using an already configured kprinter
-    bool print(QPrinter &printer) override;
+    Okular::Document::PrintError print(QPrinter &printer) override;
 
     // [INHERITED] reply to some metadata requests
     QVariant metaData(const QString &key, const QVariant &option) const override;
@@ -105,14 +106,16 @@ public:
 
     Okular::CertificateStore *certificateStore() const override;
 
+    QByteArray requestFontData(const Okular::FontInfo &font) override;
+
+#ifdef HAVE_POPPLER_SIGNING
+    static void okularToPoppler(const Okular::NewSignatureData &oData, Poppler::PDFConverter::NewSignatureData *pData);
+#endif
+
 protected:
     SwapBackingFileResult swapBackingFile(QString const &newFileName, QVector<Okular::Page *> &newPagesVector) override;
     bool doCloseDocument() override;
     Okular::TextPage *textPage(Okular::TextRequest *request) override;
-    Q_INVOKABLE Okular::Generator::PrintError printError() const;
-
-protected Q_SLOTS:
-    void requestFontData(const Okular::FontInfo &font, QByteArray *data);
 
 private:
     Okular::Document::OpenResult init(QVector<Okular::Page *> &pagesVector, const QString &password);
@@ -154,8 +157,6 @@ private:
     QBitArray rectsGenerated;
 
     QPointer<PDFOptionsPage> pdfOptionsPage;
-
-    PrintError lastPrintError;
 };
 
 #endif
